@@ -2,7 +2,7 @@ from urllib.request import urlopen
 import re
 import pyproteins.container.customCollection
 import pyproteins.container.Core
-import pyproteinsExt.pfam as pfam
+import pyproteinsext.pfam as pfam
 import json
 
 import gzip
@@ -118,13 +118,16 @@ class EntrySet(pyproteins.container.customCollection.EntrySet):
         cachePath = home     
         self.isXMLCollection = False
         self.isRedisCollection = False
-        if 'collectionXML' in kwargs:
+        if 'streamXML' or 'collectionXML' in kwargs:
             self.isXMLCollection = True
-            if kwargs['collectionXML'].endswith('.gz'):
-                with gzip.open(kwargs['collectionXML'], 'r') as gz:
-                    self.etree = parse(gz)
-            else:
-                self.etree = parse(kwargs['collectionXML'])
+            if 'streamXML' in kwargs:
+                self.etree = parse(kwargs['streamXML'])
+            elif 'collectionXML' in kwargs:
+                if kwargs['collectionXML'].endswith('.gz'):
+                    with gzip.open(kwargs['collectionXML'], 'r') as gz:
+                        self.etree = parse(gz)
+                else:
+                    self.etree = parse(kwargs['collectionXML'])
 
             self.etree_root = self.etree.getroot()
             self.index = None
@@ -245,20 +248,18 @@ class Entry(pyproteins.container.Core.Container):
     def __init__(self, id, baseUrl="http://www.uniprot.org/uniprot/", fetchable= True, fileName=None, xmlEtreeHandler=None, xmlNS=None):
         if not id:
             raise TypeError('identifier is empty')
-
         super().__init__(id, url=baseUrl + str(id) + '.xml', fileName=fileName)
         #pyproteins.container.Core.Container.__init__(self, id, url=baseUrl + str(id) + '.xml', fileName=fileName)
         
         if not xmlNS is None:
-             self._ns = xmlNS
+            self._ns = xmlNS
 
         if not xmlEtreeHandler is None:
             self.xmlHandler = xmlEtreeHandler
         else:
+            print("Search for", f"{xmlNS}entry")
             self.xmlHandler = self.getXmlHandler(fetchable=fetchable).find(f"{xmlNS}entry")
         
- 
-
         if self.xmlHandler is None:
             return None
         
@@ -284,6 +285,7 @@ class Entry(pyproteins.container.Core.Container):
         self.parseKW()
         self.parseGO()
         self.parseSequence()
+        self.parse_subcellular_location()
 
 
 # Following oarsing stages are disabled since we got rid of bs4
@@ -437,6 +439,31 @@ class Entry(pyproteins.container.Core.Container):
             if e_gene_id["id"] not in GeneID:
                 GeneID.append(e_gene_id["id"])
         return GeneID
+
+    def parse_subcellular_location(self):
+        self.subcellular_location = []
+        for citation in self._xmlFindAll('comment', type="subcellular location"):
+            for sl in self._xmlFindAll('subcellularLocation', elem = citation):
+                for location in self._xmlFindAll('location', elem = sl):
+                    self.subcellular_location.append(location.text)
+        # except : 
+        #     print("WARNING", self.AC, "subcellular location can't be parsed")
+        #     print(citation, sl, location)
+
+        # self.subcellular_location = []
+        # citations = self._xmlFindAll("comment", type="subcellular location")
+        # for citation in citations:
+        #     annotation = self._xmlFind('subcellularLocation/location', elem=citation)
+           
+
+        #     # if not annotation:
+        #     #     print("no annotation", self.AC, annotation)
+        #     # else:
+        #     try:
+        #         self.subcellular_location.append(annotation.text)
+        #     except:
+        #         print("WARNING", self.AC, "subcellular location can't be parsed")
+        #         self.subcellular_location = ['WARNING']
         
     def get_xref(self):
         # print("GET XREF")
